Read-only mirrors. Development, issues and pull requests are on GitHub.

summaryrefslogtreecommitdiffhomepage
path: root/scripts/developBuild.py
diff options
context:
space:
mode:
authorNeal Coombes2017-06-23 11:31:17 -0500
committerMartin Hořeňovský2017-06-25 15:53:59 +0200
commit396ecf6021b9c0e2b6799d091adf49b0182b180f (patch)
treeadac2932c16e45b0a7163f8df52452368b55ebd9 /scripts/developBuild.py
parenta6cdcd43aa24adf1e36edd5517a96feaeac18c25 (diff)
downloadcatch3-396ecf6021b9c0e2b6799d091adf49b0182b180f.tar.gz
Cache std::ostringstream between assertions.
This is not thread safe, but I think that was already true of Catch. The construction/destruction of the std::ostringstream is where the vast majority of time is spent per assertion. A simple test of 100000000 CHECK()s is reduced from around 60s to 7.4s
Diffstat (limited to 'scripts/developBuild.py')
0 files changed, 0 insertions, 0 deletions